import { defineComponent, reactive, watch } from 'vue';
import styles from './point.module.less';
import iconMulv from '../image/icon-mulv.svg';
import iconArrow from '../image/icon-arrow.svg';
import iconZhibo from '../image/icon-load.gif';
import iconImage from '../image/icon-image.svg';
import iconImageActive from '../image/icon-image-active.svg';
import iconVideo from '../image/icon-video.svg';
import iconVideoActive from '../image/icon-video-active.svg';
import iconSong from '../image/icon-song.svg';
import iconSongActive from '../image/icon-song-active.svg';
import { Collapse, Icon, Image } from 'vant';
export default defineComponent({
  name: 'points',
  props: {
    data: {
      type: Array,
      default: () => []
    },
    tabActive: {
      type: String,
      default: ''
    },
    itemActive: {
      type: String,
      default: ''
    }
  },
  emits: ['handleSelect'],
  setup(props, { emit }) {
    const pointData = reactive({
      active: props.tabActive[0] || '',
      childActive: props.tabActive[1] || ''
    });
    watch(
      () => props.tabActive,
      () => {
        pointData.active = props.tabActive[0] || '';
        pointData.childActive = props.tabActive[1] || '';
      }
    );

    console.log(
      pointData.active,
      'pointData.active',
      props.data,
      props.tabActive
    );

    // 获取对应图片
    const getImage = (item: any) => {
      if (item.type === 'VIDEO') {
        return props.itemActive == item.id ? iconVideoActive : iconVideo;
      } else if (['IMAGE', 'IMG'].includes(item.type)) {
        return props.itemActive == item.id ? iconImageActive : iconImage;
      } else if (item.type === 'SONG') {
        return props.itemActive == item.id ? iconSongActive : iconSong;
      } else {
        return props.itemActive == item.id ? iconVideoActive : iconVideo;
      }
    };
    return () => (
      <div class={styles.container}>
        <div class={styles.pointHead}>
          <img src={iconMulv} />
          课件列表
        </div>
        <div class={styles.content}>
          <Collapse
            class={styles.collapse}
            modelValue={pointData.active}
            onUpdate:modelValue={(val: any) => {
              pointData.active = val;
            }}
            accordion>
            {props.data.map((item: any, index: number) => {
              return (
                <div
                  class={[
                    styles.item,
                    props.itemActive == item.id ? styles.itemActive : ''
                  ]}
                  onClick={() => {
                    emit('handleSelect', {
                      itemActive: item.id,
                      tabName: item.name
                    });
                  }}>
                  <Image src={getImage(item)} class={styles.itemImage} />
                  <span class={["van-ellipsis", styles.name]}>
                    {item.name}
                  </span>
                  <Icon name={iconZhibo} />
                </div>
              );
            })}
          </Collapse>
        </div>
      </div>
    );
  }
});
